/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.api.resources;

import java.util.Arrays;
import java.util.Collections;

import org.apache.ambari.server.controller.spi.Resource;

/**
 * Upgrade resource definition.
 */
public class UpgradeResourceDefinition extends SimpleResourceDefinition {

  public static final String SKIP_SERVICE_CHECKS_DIRECTIVE = "skip_service_checks";

  /**
   * Constructor.
   */
  public UpgradeResourceDefinition() {
    super(Resource.Type.Upgrade,
        "upgrade",
        "upgrades",
        Collections.singleton(Resource.Type.UpgradeGroup),
        Collections.singletonMap(DirectiveType.CREATE,
            Arrays.asList(SKIP_SERVICE_CHECKS_DIRECTIVE)));
  }
}
